       IDENTIFICATION DIVISION.
       PROGRAM-ID.    ITUPDC01.
       AUTHOR.        SIMOTIME TECHNOLOGIES.
      *****************************************************************
      * Copyright (C) 1987-2019 SimoTime Technologies.                *
      *                                                               *
      * All rights reserved.  Unpublished, all rights reserved under  *
      * copyright law and international treaty.  Use of a copyright   *
      * notice is precautionary only and does not imply publication   *
      * or disclosure.                                                *
      *                                                               *
      * Permission to use, copy, modify and distribute this software  *
      * for any non-commercial purpose and without fee is hereby      *
      * granted, provided the SimoTime copyright notice appear on all *
      * copies of the software. The SimoTime name or Logo may not be  *
      * used in any advertising or publicity pertaining to the use    *
      * of the software without the written permission of SimoTime    *
      * Technologies.                                                 *
      *                                                               *
      * Permission to use, copy, modify and distribute this software  *
      * for any commercial purpose requires a fee to be paid to       *
      * SimoTime Technologies. Once the fee is received by SimoTime   *
      * the latest version of the software will be delivered and a    *
      * license will be granted for use within an enterprise,         *
      * provided the SimoTime copyright notice appear on all copies   *
      * of the software. The SimoTime name or Logo may not be used    *
      * in any advertising or publicity pertaining to the use of the  *
      * software without the written permission of SimoTime           *
      * Technologies.                                                 *
      *                                                               *
      * SimoTime Technologies makes no warranty or representations    *
      * about the suitability of the software for any purpose. It is  *
      * provided "AS IS" without any expressed or implied warranty,   *
      * including the implied warranties of merchantability, fitness  *
      * for a particular purpose and non-infringement. SimoTime       *
      * Technologies shall not be liable for any direct, indirect,    *
      * special or consequential damages resulting from the loss of   *
      * use, data or projects, whether in an action of contract or    *
      * tort, arising out of or in connection with the use or         *
      * performance of this software                                  *
      *                                                               *
      * SimoTime Technologies                                         *
      * 15 Carnoustie Drive                                           *
      * Novato, CA 94949-5849                                         *
      * 415.883.6565                                                  *
      *                                                               *
      * RESTRICTED RIGHTS LEGEND                                      *
      * Use, duplication, or disclosure by the Government is subject  *
      * to restrictions as set forth in subparagraph (c)(1)(ii) of    *
      * the Rights in Technical Data and Computer Software clause at  *
      * DFARS 52.227-7013 or subparagraphs (c)(1) and (2) of          *
      * Commercial  Computer Software - Restricted Rights  at 48      *
      * CFR 52.227-19, as applicable.  Contact SimoTime Technologies, *
      * 15 Carnoustie Drive, Novato, CA 94949-5849.                   *
      *                                                               *
      *****************************************************************
      *      This program is provided by SimoTime Technologies        *
      *        Our e-mail address is: helpdesk@simotime.com           *
      *     Also, visit our Web Site at http://www.simotime.com       *
      *                                                               *
      *****************************************************************
      *
      *****************************************************************
      * Source Member: ITUPDC01.CBL
      * Copy Files:    QQSMREC1.CPY
      *                ITEMCB01
      *****************************************************************
      *
      * ITUPDC01 - Execute ITUPDC01 to read a QSAM file and  update
      * a VSAM Keyed Sequential Data Set (KSDS).
      *
      * EXECUTION or CALLING PROTOCOL
      * -----------------------------
      * Use standard JCL to EXECUTE or ANIMATE.
      *
      * DESCRIPTION
      * -----------
      * This single COBOL program will read an 80-byte, EBCDIC, QSAM
      * file an populate or update an empty or existing KSDS, VSAM
      * data set.
      *
      *                      ************
      *                      * ITUPDJ01 *
      *                      ********jcl*
      *                           *
      *                           *
      *     ************     ************     ************
      *     * ITEMSQ01 *-----* ITUPDC01 *-----* ITEMMAST *
      *     *******qsam*     ********cbl*     *******vsam*
      *                           *
      *                           *
      *                      ************
      *                      *   EOJ    *
      *                      ************
      *
      *****************************************************************
      * This program will read the input file and update the master
      * file (SYSMLR2). The format of the input file (SYSMLR1) is
      * as follows.
      *
      * Position Length Description...
      *  ------   ----  -----------------------------------------------
      *    01      03   Record Idendifier
      *                 /DE Item Description change or correction
      *                 /UM Unit of Measure
      *                 /CS Cost
      *                 /PR Price
      *    04      12   The Key Field
      *    16      nn   Length based on Record Identifier
      *
      *****************************************************************
      *
      * MAINTENANCE
      * -----------
      * 1997/02/27 Simmons, Created program.
      * 1997/02/27 Simmons, No changes to date.
      *
      *****************************************************************
      *
       ENVIRONMENT DIVISION.
       INPUT-OUTPUT   SECTION.
       FILE-CONTROL.

      *****************************************************************
           SELECT ITEMSQ01-FILE
               ASSIGN       to ITEMSQ01
               ORGANIZATION is SEQUENTIAL
               ACCESS MODE  is SEQUENTIAL
               FILE STATUS  is ITEMSQ01-STATUS.
           SELECT ITEMMAST-FILE
               ASSIGN       to ITEMMAST
               ORGANIZATION is indexed
               ACCESS MODE  is RANDOM
               RECORD KEY   is ITEM-NUMBER
               FILE STATUS  is ITEMMAST-STATUS.

      *****************************************************************
       DATA DIVISION.
       FILE SECTION.

      *****************************************************************
       FD   ITEMSQ01-FILE
            RECORD CONTAINS 80 CHARACTERS.
       COPY QSMCPYB2.

       FD  ITEMMAST-FILE.
       COPY ITEMCB01.

       WORKING-STORAGE SECTION.
      *****************************************************************
      *    Data-structure for Title and Copyright...
      *****************************************************************
       01  SIM-TITLE.
           05  T1 pic X(11) value '* ITUPDC01 '.
           05  T2 pic X(34) value 'Read ITEMSQ01, Update ITEMMAST    '.
           05  T3 pic X(10) value ' v07.04.18'.
           05  T4 pic X(24) value ' http://www.simotime.com'.
       01  SIM-COPYRIGHT.
           05  C1 pic X(11) value '* ITUPDC01 '.
           05  C2 pic X(20) value 'Copyright 1987-2019 '.
           05  C3 pic X(28) value '   SimoTime Technologies    '.
           05  C4 pic X(20) value ' All Rights Reserved'.

       01  SIM-THANKS-01.
           05  C1 pic X(11) value '* ITUPDC01 '.
           05  C2 pic X(32) value 'Thank you for using this program'.
           05  C3 pic X(32) value ' provided from SimoTime Technolo'.
           05  C4 pic X(04) value 'gies'.

       01  SIM-THANKS-02.
           05  C1 pic X(11) value '* ITUPDC01 '.
           05  C2 pic X(32) value 'Please send all inquires or sugg'.
           05  C3 pic X(32) value 'estions to the helpdesk@simotime'.
           05  C4 pic X(04) value '.com'.

       01  ITEMMAST-STATUS.
           05  ITEMMAST-STAT1      pic X.
           05  ITEMMAST-STAT2      pic X.

       01  ITEMSQ01-STATUS.
           05  ITEMSQ01-STAT1      pic X.
           05  ITEMSQ01-STAT2      pic X.

       01  IO-STATUS.
           05  IO-STAT1            pic X.
           05  IO-STAT2            pic X.
       01  TWO-BYTES.
           05  TWO-BYTES-LEFT      pic X.
           05  TWO-BYTES-RIGHT     pic X.
       01  TWO-BYTES-BINARY        redefines TWO-BYTES pic 9(4) comp.

       01  END-OF-FILE             pic X(3)    value 'NO '.

      *****************************************************************
      *    Buffer used for posting messages to the console.
      *****************************************************************
       01  MESSAGE-BUFFER.
           05  MESSAGE-HEADER      pic X(11)   value '* ITUPDC01 '.
           05  MESSAGE-TEXT.
               10  MESSAGE-TEXT-1  pic X(68)   value SPACES.
               10  MESSAGE-TEXT-2  pic X(188)  value SPACES.

       01  ITEMSQ01-FLAG           pic X       value 'N'.

       01  APPL-RESULT             pic S9(9)   comp.
           88  APPL-AOK            value 0.
           88  APPL-EOF            value 16.

       01  NBR-S09V2-SLS           pic S9(9)V9(2)   value 0
                                   SIGN LEADING SEPARATE.
       01  NBR-S09V2-SLS-X         redefines NBR-S09V2-SLS
                                   pic X(12).
       01  NBR-U05                 pic 9(5)    value 0.
       01  PT-1                    pic 9(3)    value 0.
       01  PT-2                    pic 9(3)    value 0.

      *****************************************************************
      *    Working Storage items for the Z-ROUTINES...
      *    -----------------------------------------------------------*
       01  Z-DATE-01.
           05  Z-DATE-01-CC   pic 9(02).
           05  Z-DATE-01-YY   pic 9(02).
           05  Z-DATE-01-MM   pic 9(02).
           05  Z-DATE-01-DD   pic 9(02).
       01  Z-TIME-01.
           05  Z-TIME-01-HH   pic X(02).
           05  Z-TIME-01-NN   pic X(02).
           05  Z-TIME-01-SS   pic X(02).
           05  Z-TIME-01-TT   pic X(02).

       01  Z-DATE-02.
           05  Z-DATE-02-CC   pic 9(02).
           05  Z-DATE-02-YY   pic 9(02).
           05  FILLER         pic X        value '/'.
           05  Z-DATE-02-MM   pic 9(02).
           05  FILLER         pic X        value '/'.
           05  Z-DATE-02-DD   pic 9(02).
       01  Z-TIME-02.
           05  Z-TIME-02-HH   pic X(02).
           05  FILLER         pic X        value ':'.
           05  Z-TIME-02-NN   pic X(02).
           05  FILLER         pic X        value ':'.
           05  Z-TIME-02-SS   pic X(02).
           05  FILLER         pic X        value ':'.
           05  Z-TIME-02-TT   pic X(02).

       01  Z-X12                   pic 9(3)    value 0.
       01  Z-WORK-12               pic X(12)   value SPACES.

      *****************************************************************
       PROCEDURE DIVISION.

           perform Z-POST-COPYRIGHT.

           move ZERO to RETURN-CODE

           perform ITEMSQ01-OPEN.
           perform ITEMMAST-OPEN.

           perform until END-OF-FILE = 'YES'
               if  END-OF-FILE = 'NO '
                   perform ITEMSQ01-GET
                   if  END-OF-FILE = 'NO '
                       move QSAM-B2-RECORD to MESSAGE-TEXT
                       perform Z-DISPLAY-MESSAGE-TEXT
                       move QSAM-B2-KEY to ITEM-NUMBER
                       perform ITEMMAST-GET
                       if  ITEMMAST-STATUS = 23
                            initialize ITEM-DATA
                        end-if
                       perform MOVE-QSAM-FIELD-TO-KSDS-RECORD
                       if  ITEMSQ01-FLAG = 'Y'
                           if  APPL-AOK
                               perform DATE-TIME-TOKEN-STAMP
                               perform ITEMMAST-REWRITE
                           else
                               perform DATE-TIME-TOKEN-STAMP
                               perform ITEMMAST-WRITE
                           end-if
                       end-if
                   end-if
               end-if
           end-perform.

           perform ITEMMAST-CLOSE.
           perform ITEMSQ01-CLOSE.

           display 'ITUPDC01 ITEMMAST-HAS-BEEN-UPDATED' upon console
           display 'ITUPDC01 NORMAL-END-OF-JOB...'      upon console

           perform Z-THANK-YOU.

           GOBACK.

      *****************************************************************
      * The following routines are in alphabetic sequence.            *
      *****************************************************************

      *****************************************************************
       DATE-TIME-TOKEN-STAMP.
           perform Z-GET-DATE-AND-TIME
           move Z-DATE-01 to ITEM-LADATE
           move Z-TIME-01 to ITEM-LATIME
           move '000'     to ITEM-TOKEN
           exit.

      *****************************************************************
       MOVE-QSAM-FIELD-TO-KSDS-RECORD.
           move 'Y' to ITEMSQ01-FLAG
           evaluate QSAM-B2-ID
               when '/DE' move QSAM-B2-DATA to ITEM-DESCRIPTION
               when '/UM' move QSAM-B2-DATA to ITEM-UNIT-OF-MEASURE
               when '/CS' perform UPDATE-COST
               when '/PR' perform UPDATE-PRICE
               when '/OH' perform UPDATE-ONHAND
               when other move 'N' to ITEMSQ01-FLAG
           end-evaluate

           exit.

      *****************************************************************
       UPDATE-COST.
           move QSAM-B2-DATA to Z-WORK-12
           perform Z-RIGHT-ADJUST-Z-WORK-12
      *    ITEM-COST
           move Z-WORK-12(11:2) to NBR-S09V2-SLS-X(11:2)
           move Z-WORK-12(1:9)  to NBR-S09V2-SLS-X(2:9)
           move '+'             to NBR-S09V2-SLS-X(1:1)
           add NBR-S09V2-SLS to ZERO giving ITEM-COST
           exit.

      *****************************************************************
       UPDATE-PRICE.
           move QSAM-B2-DATA to Z-WORK-12
           perform Z-RIGHT-ADJUST-Z-WORK-12
      *    ITEM-PRICE
           move Z-WORK-12(11:2) to NBR-S09V2-SLS-X(11:2)
           move Z-WORK-12(1:9)  to NBR-S09V2-SLS-X(2:9)
           move '+'             to NBR-S09V2-SLS-X(1:1)
           add NBR-S09V2-SLS to ZERO giving ITEM-PRICE
           exit.

      *****************************************************************
       UPDATE-ONHAND.
           move QSAM-B2-DATA to Z-WORK-12
           perform Z-RIGHT-ADJUST-Z-WORK-12
      *    ITEM-ONHAND
           move Z-WORK-12(8:5) to NBR-U05
           add NBR-U05 to ZERO giving ITEM-QTY-ONHAND
           exit.

      *****************************************************************
      * Routines to do a sequential read of the QSAM file.            *
      *****************************************************************
       ITEMSQ01-GET.
           read ITEMSQ01-FILE
           if  ITEMSQ01-STATUS = '00'
               subtract APPL-RESULT from APPL-RESULT
           else
               if  ITEMSQ01-STATUS = '10'
                   add 16 to ZERO giving APPL-RESULT
               else
                   add 12 to ZERO giving APPL-RESULT
               end-if
           end-if
           if  APPL-AOK
               CONTINUE
           else
               if  APPL-EOF
                   move 'YES' to END-OF-FILE
               else
                   move 'ITUPDC01 ITEMSQ01-FAILURE-GET...'
                     to   MESSAGE-TEXT
                   move ITEMSQ01-STATUS to IO-STATUS
                   perform Z-DISPLAY-MESSAGE-TEXT
                   perform Z-DISPLAY-IO-STATUS
                   perform Z-ABEND-PROGRAM
               end-if
           end-if
           exit.
      *---------------------------------------------------------------*
       ITEMSQ01-OPEN.
           add 8 to ZERO giving APPL-RESULT.
           open input ITEMSQ01-FILE
           if  ITEMSQ01-STATUS = '00'
               subtract APPL-RESULT from APPL-RESULT
           else
               add 12 to ZERO giving APPL-RESULT
           end-if
           if  APPL-AOK
               CONTINUE
           else
               move 'ITUPDC01 ITEMSQ01-FAILURE-OPEN...'
                 to MESSAGE-TEXT
               move ITEMSQ01-STATUS to IO-STATUS
               perform Z-DISPLAY-MESSAGE-TEXT
               perform Z-DISPLAY-IO-STATUS
               perform Z-ABEND-PROGRAM
           end-if
           exit.
      *---------------------------------------------------------------*
       ITEMSQ01-CLOSE.
           add 8 to ZERO giving APPL-RESULT.
           close ITEMSQ01-FILE
           if  ITEMSQ01-STATUS = '00'
               subtract APPL-RESULT from APPL-RESULT
           else
               add 12 to ZERO giving APPL-RESULT
           end-if

           if  APPL-AOK
               CONTINUE
           else
               move 'ITUPDC01, ITEMSQ01, FAILURE, CLOSE...'
                 to MESSAGE-TEXT
               move ITEMSQ01-STATUS to IO-STATUS
               perform Z-DISPLAY-MESSAGE-TEXT
               perform Z-DISPLAY-IO-STATUS
               perform Z-ABEND-PROGRAM
           end-if
           exit.

      *****************************************************************
      * Routines to do a read by KEY of the KSDS, VSAM Data Set. If   *
      * the read is successful then the record may be updated else a  *
      * new record may be added.                                      *
      *****************************************************************
       ITEMMAST-GET.
           read ITEMMAST-FILE
           if  ITEMMAST-STATUS = '00'
               subtract APPL-RESULT from APPL-RESULT
           else
               if  ITEMMAST-STATUS = '10'
                   add 16 to ZERO giving APPL-RESULT
               else
                   add 12 to ZERO giving APPL-RESULT
               end-if
           end-if
           if  APPL-AOK
               CONTINUE
           else
               if  APPL-EOF
                   move 'YES' to END-OF-FILE
               end-if
           end-if
           exit.
      *---------------------------------------------------------------*
       ITEMMAST-WRITE.
           write ITEM-RECORD
           if  ITEMMAST-STATUS = '00'
               subtract APPL-RESULT from APPL-RESULT
           else
               if  ITEMMAST-STATUS = '10'
                   add 16 to ZERO giving APPL-RESULT
               else
                   add 12 to ZERO giving APPL-RESULT
               end-if
           end-if
           if  APPL-AOK
               CONTINUE
           else
               if  APPL-EOF
                   move 'YES' to END-OF-FILE
               else
                   move 'ITUPDC01 ITEMMAST-FAILURE-WRITE...'
                     to   MESSAGE-TEXT
                   move ITEMMAST-STATUS to IO-STATUS
                   perform Z-DISPLAY-MESSAGE-TEXT
                   perform Z-DISPLAY-IO-STATUS
                   perform Z-ABEND-PROGRAM
               end-if
           end-if
           exit.
      *---------------------------------------------------------------*
       ITEMMAST-REWRITE.
           REWRITE ITEM-RECORD
           if  ITEMMAST-STATUS = '00'
               subtract APPL-RESULT from APPL-RESULT
           else
               if  ITEMMAST-STATUS = '10'
                   add 16 to ZERO giving APPL-RESULT
               else
                   add 12 to ZERO giving APPL-RESULT
               end-if
           end-if
           if  APPL-AOK
               CONTINUE
           else
               if  APPL-EOF
                   move 'YES' to END-OF-FILE
               else
                   move 'ITUPDC01 ITEMMAST-FAILURE-REWRITE...'
                     to   MESSAGE-TEXT
                   move ITEMMAST-STATUS to IO-STATUS
                   perform Z-DISPLAY-MESSAGE-TEXT
                   perform Z-DISPLAY-IO-STATUS
                   perform Z-ABEND-PROGRAM
               end-if
           end-if
           exit.
      *---------------------------------------------------------------*
       ITEMMAST-OPEN.
           add 8 to ZERO giving APPL-RESULT.
           open I-O ITEMMAST-FILE
           if  ITEMMAST-STATUS = '35'
               move 'ITUPDC01 ITEMMAST-FAILURE-OPEN-IO...'
                 to MESSAGE-TEXT
               perform Z-DISPLAY-MESSAGE-TEXT
               move ITEMMAST-STATUS to IO-STATUS
               perform Z-DISPLAY-IO-STATUS
               move 'ITUPDC01 ITEMMAST-ATTEMPT-OPEN-OUTPUT...'
                 to MESSAGE-TEXT
               perform Z-DISPLAY-MESSAGE-TEXT
               open output ITEMMAST-FILE
           end-if
           if  ITEMMAST-STATUS = '00'
               subtract APPL-RESULT from APPL-RESULT
           else
               add 12 to ZERO giving APPL-RESULT
           end-if
           if  APPL-AOK
               CONTINUE
           else
               move 'ITUPDC01 ITEMMAST-FAILURE-OPEN...'
                 to MESSAGE-TEXT
               move ITEMMAST-STATUS to IO-STATUS
               perform Z-DISPLAY-MESSAGE-TEXT
               perform Z-DISPLAY-IO-STATUS
               perform Z-ABEND-PROGRAM
           end-if
           exit.
      *---------------------------------------------------------------*
       ITEMMAST-CLOSE.
           add 8 to ZERO giving APPL-RESULT.
           close ITEMMAST-FILE
           if  ITEMMAST-STATUS = '00'
               subtract APPL-RESULT from APPL-RESULT
           else
               add 12 to ZERO giving APPL-RESULT
           end-if
           if  APPL-AOK
               CONTINUE
           else
               move 'ITUPDC01 ITEMMAST-FAILURE-CLOSE...'
                 to   MESSAGE-TEXT
               move ITEMMAST-STATUS to IO-STATUS
               perform Z-DISPLAY-MESSAGE-TEXT
               perform Z-DISPLAY-IO-STATUS
               perform Z-ABEND-PROGRAM
           end-if
           exit.

      *****************************************************************
      * The following Z-Routines perform administrative tasks         *
      * for this program.                                             *
      *****************************************************************
      *
      *****************************************************************
      * ABEND the program, post a message to the console and issue    *
      * a STOP RUN.                                                   *
      *****************************************************************
       Z-ABEND-PROGRAM.
           if  MESSAGE-TEXT not = SPACES
               perform Z-DISPLAY-MESSAGE-TEXT
           end-if
           move 'ITUPDC01 PROGRAM-IS-ABENDING...'  to MESSAGE-TEXT
           perform Z-DISPLAY-MESSAGE-TEXT
           add 12 to ZERO giving RETURN-CODE
           STOP RUN.
      *    exit.

      *****************************************************************
       Z-GET-DATE-AND-TIME.
      *    This routine requires COBOL for 390 dialect because of
      *    the use of the YYYYMMDD on the ACCEPT statement.
           accept Z-DATE-01 from DATE YYYYMMDD
           accept Z-TIME-01 from TIME

           move 'ccyy/mm/dd'   to Z-DATE-02
           move Z-DATE-01(1:4) to Z-DATE-02(1:4)
           move Z-DATE-01(5:2) to Z-DATE-02(6:2)
           move Z-DATE-01(7:2) to Z-DATE-02(9:2)

           move 'hh:mm:ss:dd'  to Z-TIME-02
           move Z-TIME-01(1:2) to Z-TIME-02(1:2)
           move Z-TIME-01(3:2) to Z-TIME-02(4:2)
           move Z-TIME-01(5:2) to Z-TIME-02(7:2)
           move Z-TIME-01(7:2) to Z-TIME-02(10:2)

           exit.

      *****************************************************************
      * Display the file status bytes. This routine will display as   *
      * two digits if the full two byte file status is numeric. If    *
      * second byte is non-numeric then it will be treated as a       *
      * binary number.                                                *
      *****************************************************************
       Z-DISPLAY-IO-STATUS.
           if  IO-STATUS not NUMERIC
           or  IO-STAT1 = '9'
               subtract TWO-BYTES-BINARY from TWO-BYTES-BINARY
               move IO-STAT2 to TWO-BYTES-RIGHT
               display '* ITUPDC01 FILE-STATUS-' IO-STAT1 '/'
                       TWO-BYTES-BINARY upon console
               display '* ITUPDC01 FILE-STATUS-' IO-STAT1 '/'
                       TWO-BYTES-BINARY
           else
               display '* ITUPDC01 FILE-STATUS-' IO-STATUS upon console
               display '* ITUPDC01 FILE-STATUS-' IO-STATUS
           end-if
           exit.

      *****************************************************************
       Z-DISPLAY-MESSAGE-TEXT.
           if MESSAGE-TEXT-2 = SPACES
               display MESSAGE-BUFFER(1:79)
           else
               display MESSAGE-BUFFER
           end-if
           move all SPACES to MESSAGE-TEXT
           exit.

      *****************************************************************
      * Delete all characters to the right of the first space then
      * right-adjust with zero fill. This routine works with a single,
      * twelve character field and does not require a work area.
      *****************************************************************
       Z-RIGHT-ADJUST-Z-WORK-12.
      *    The following INSPECT statement will erase to end-of-field
      *    any characters after the first space character.
           inspect Z-WORK-12
                   replacing CHARACTERS by ' ' after initial ' '

      *    The following IF logic is for performance. It quickly
      *    reduces the number of loops for the PERFORM logic.
           if  Z-WORK-12(7:6) = SPACES
               if  Z-WORK-12(4:3) = SPACES
                   move Z-WORK-12(1:3) to Z-WORK-12(10:3)
                   move all ZEROES     to Z-WORK-12(1:9)
               else
                   move Z-WORK-12(1:6) to Z-WORK-12(7:6)
                   move all ZEROES     to Z-WORK-12(1:6)
               end-if
           else
               if  Z-WORK-12(10:3) = SPACES
      *            The following three MOVE statements are used to
      *            avoid a potential problem with an overlapping MOVE.
                   move Z-WORK-12(7:3) to Z-WORK-12(10:3)
                   move Z-WORK-12(4:3) to Z-WORK-12(7:3)
                   move Z-WORK-12(1:3) to Z-WORK-12(4:3)
                   move all ZEROES     to Z-WORK-12(1:3)
               end-if
           end-if

           perform until Z-WORK-12(12:1) not = SPACE
               if  Z-WORK-12(12:1) = SPACE
                   add 11 to ZERO giving Z-X12
                   perform 11 times
                     move Z-WORK-12(Z-X12:1) to Z-WORK-12(Z-X12 + 1:1)
                     subtract 1 from Z-X12
                   end-perform
                   move ZERO to Z-WORK-12(1:1)
               end-if
           end-perform
           exit.

      *****************************************************************
       Z-POST-COPYRIGHT.
      *    display SIM-TITLE
      *    display SIM-COPYRIGHT
           exit.

      *****************************************************************
       Z-THANK-YOU.
      *    display SIM-THANKS-01
      *    display SIM-THANKS-02
           exit.
      *****************************************************************
      *      This example is provided by SimoTime Technologies        *
      *        Our e-mail address is: helpdesk@simotime.com           *
      *     Also, visit our Web Site at http://www.simotime.com       *
      *****************************************************************
